@@ -1,6 +1,7 @@
 """Add syntatic sugar for configuration"""
 import inspect
 import warnings
+import sys
 
 default_clean = "[Tt]est*"
 
@@ -8,9 +9,10 @@ defaults = dict(
     rewrite_asserts=True,
     magics=True,
     clean=default_clean,
-    addopts=("-q",),
+    addopts=("-q", "--color=yes"),
     run_in_thread=False,
     defopts=True,
+    display_columns=100,
 )
 
 current_config = dict(
@@ -20,6 +22,7 @@ current_config = dict(
     addopts=(),
     run_in_thread=False,
     defopts=True,
+    display_columns=100,
 )
 
 _rewrite_transformer = None
@@ -57,6 +60,7 @@ def autoconfig(
     addopts=default,
     run_in_thread=default,
     defopts=default,
+    display_columns=default,
 ):
     """Configure ``ipytest`` with reasonable defaults.
 
@@ -82,6 +86,7 @@ def config(
     addopts=keep,
     run_in_thread=keep,
     defopts=keep,
+    display_columns=keep,
 ):
     """Configure `ipytest`
 
@@ -99,7 +104,7 @@ def config(
     * ``addopts`` (default: ``()``): pytest command line arguments to prepend
       to every pytest invocation. For example setting
       ``ipytest.config(addopts=['-qq'])`` will execute pytest with the least
-      verbosity
+      verbosity. Consider adding ``--color=yes`` to force color output
     * ``run_in_thread`` (default: ``False``): if ``True``, pytest will be run a
       separate thread. This way of running is required when testing async
       code with ``pytest_asyncio`` since it starts a separate event loop
@@ -107,6 +112,9 @@ def config(
       current module to the arguments passed to pytest. If ``False`` only the
       arguments given and ``adopts`` are passed. Such a setup may be helpful
       to customize the test selection
+    * ``display_columns`` (default: ``100``) if not `False`, configure Pytest
+      to use the given number of columns for its output. This option will
+      temporarily override the ``COLUMNS`` environment variable.
     """
     args = collect_args()
     new_config = {
@@ -145,17 +153,81 @@ def configure_rewrite_asserts(enable):
 
 def configure_magics(enable):
     from IPython import get_ipython
-    from ._impl import run_pytest, run_pytest_clean
+    from ._impl import pytest_magic
 
     if enable:
         shell = get_ipython()
-        shell.register_magic_function(run_pytest, "cell", "run_pytest")
-        shell.register_magic_function(run_pytest_clean, "cell", "run_pytest[clean]")
+        shell.register_magic_function(pytest_magic, "cell", "ipytest")
+        shell.register_magic_function(_deprecated_pytest_magic, "cell", "run_pytest")
+        shell.register_magic_function(
+            _deprecated_pytest_clean_magic, "cell", "run_pytest[clean]"
+        )
 
     else:
         warnings.warn("IPython does not support de-registering magics.")
 
 
+def _deprecated_pytest_magic(line, cell):
+    print(
+        "%%run_pytest[clean] and %%run_pytest are deprecated in favor of "
+        "%%ipytest. %%ipytest will clean tests, evaluate the cell and then "
+        "run pytest. To disable cleaning, configure ipytest with "
+        "ipytest.config(clean=False).",
+        file=sys.stderr,
+    )
+    import shlex
+    from IPython import get_ipython
+    from ._impl import run
+
+    try:
+        get_ipython().run_cell(cell)
+
+    except TypeError as e:
+        if "raw_cell" in str(e):
+            raise RuntimeError(
+                "The ipytest magic cannot evaluate the cell. Most likely you "
+                "are running a modified ipython version. Consider using "
+                "`ipytest.run` and `ipytest.clean_tests` directly."
+            ) from e
+
+        else:
+            raise e
+
+    run(*shlex.split(line))
+
+
+def _deprecated_pytest_clean_magic(line, cell):
+    print(
+        "%%run_pytest[clean] and %%run_pytest are deprecated in favor of "
+        "%%ipytest. %%ipytest will clean tests, evaluate the cell and then "
+        "run pytest. To disable cleaning, configure ipytest with "
+        "ipytest.config(clean=False).",
+        file=sys.stderr,
+    )
+    import shlex
+    from IPython import get_ipython
+    from ._impl import clean_tests, run
+
+    if current_config["clean"] is not False:
+        clean_tests(current_config["clean"])
+
+    try:
+        get_ipython().run_cell(cell)
+
+    except TypeError as e:
+        if "raw_cell" in str(e):
+            raise RuntimeError(
+                "The ipytest magic cannot evaluate the cell. Most likely you "
+                "are running a modified ipython version. Consider using "
+                "`ipytest.run` and `ipytest.clean_tests` directly."
+            ) from e
+
+        else:
+            raise e
+
+    run(*shlex.split(line))
+
+
 def replace_with_default(sentinel, value, default):
     return default if value is sentinel else value
 
